function Yst=hasegawa79_st_test(xeval)

% This code calculates the acoustic radiation force on a spherical
% particle under standing wave. The formulation is taken from:
%
% Hasegawa, T. (1979) Acoustic radiation force on a sphere in a
% quasistationary wave field-theory.
%
% The formulation here includes the correction pointed out by Mitri (2005)
% and Glynne-Jones (2013).  
% rhop=3900; % Particle density
% c1=6375; % Compression wave velocity of particle
% c2=3130; % Shear wave velocity of particle
% sigma=0.22; % Poisson's ratio
% sigma=0.5

%Nickel
rhop=1110; % Particle density
c1=2620; % Compression wave velocity of particle
c2=1070; % Shear wave velocity of particle

%Steel glynne-jones
% rhop=7890; % Particle density
% c1=5790; % Compression wave velocity of particle
% c2=3100; % Shear wave velocity of particle
% sigma=0.27; % Poisson's ratio


%%%Glycerine
% rholiq=1260; % Liquid density
% cliq=1962; % Liquid speed of sound

%%%Water
rholiq=1000; % Liquid density
cliq=1480; % Liquid speed of sound

x=sym('x'); % x=k*a

x1=x*cliq/c1; 
x2=x*cliq/c2;
n=sym('n'); %Bessel order
n1=sym('n1'); %Bessel order, n+1


%% Bessel functions
jn=sphbes1(n,x);
jn1=sphbes1(n1,x);
djn=(2.^(1/2).*pi.^(1/2).*besselj(n - 1/2, x).*(1./x).^(1./2))./2 - (2.^(1./2).*pi.^(1./2).*besselj(n + 1/2, x).*(n + 1).*(1./x).^(3./2))./2;
ddjn=(2.^(1./2).*pi.^(1/2).*besselj(n + 1/2, x).*(1./x).^(1./2).*(n.^2 + 3.*n - x.^2 + 2))./(2.*x.^2) - 2.^(1./2).*pi.^(1/2).*besselj(n - 1./2, x).*(1./x).^(3./2);

nn=sphbes2(n,x);
nn1=sphbes2(n1,x);
dnn=(2.^(1./2).*pi.^(1./2).*bessely(n - 1./2, x).*(1./x).^(1./2))./2 - (2.^(1./2).*pi.^(1./2).*bessely(n + 1./2, x).*(n + 1).*(1./x).^(3./2))./2;

%% Key variables
Fn=Fcalc(jn,jn1,djn,ddjn,x,x1,x2,rhop,rholiq,n);

[alphn,betan]=alphbetacalc(Fn,jn,jn1,djn,nn,nn1,dnn,x,n);


for ii=0:20
   alphn_ev(ii+1)=subs(alphn,{n n1},{ii ii+1});
   betan_ev(ii+1)=subs(betan,{n n1},{ii ii+1});
end




% % % % % for ii=0:20
% % % % %     alphn_ev(ii+1)=subs(alphn,n,ii);
% % % % %     betan_ev(ii+1)=subs(betan,n,ii);
% % % % %     jn_ev(ii+1)=subs(jn,n,ii);
% % % % %     nn_ev(ii+1)=subs(nn,n,ii);
% % % % % end % Evaluation of parameters for all n

Yphi=0;

%% Hasegawa (1979), ARF under stationary wave

for ii=1:20
   Yphi=Yphi+(ii)*(-1)^(ii)*(betan_ev(ii)*(1+2*alphn_ev(ii+1))-betan_ev(ii+1)*(1+2*alphn_ev(ii))); 
end

Yphi=Yphi.*8/x^2;

%% Substitution: Substitute any x=k*a value to evaluate ARF
% xeval=0.2562;
% xeval=0.25:0.25:8;
aa=subs(Yphi,x,xeval);
Yst=-double(aa);
plot(xeval,Yst);
% hasegawa79_steeldata;
% hold on;
% plot(steeldata(:,1),steeldata(:,2));

% hold on;
% cc=[0.003718 0.0945 0.1852 0.3839 0.5510 0.6359 0.6827 0.7468 0.8199 0.8644 0.8734 0.8827 0.8908 0.8888 0.8830 0.8772 0.8716 0.8586 0.8265 0.7222 0.6077 0.9081 0.9265 0.9242 0.9197 0.9121 0.8865 0.9051 0.8750 0.7959 0.6259 0.8442];
% plot(0.25:0.25:8, cc);
% end
