% This code calculates the acoustic radiation force on a spherical
% particle under standing wave. The formulation is taken from:
%
% Hasegawa, T. (1979) Acoustic radiation force on a sphere in a
% quasistationary wave field-theory.
%
% The formulation here includes the correction pointed out by Mitri (2005)
% and Glynne-Jones (2013). 

function Yst=hasegawa79_st(xeval,MASSsc,LENGTHsc,TIMEsc)

%Nickel
rhop=8900*LENGTHsc^2/(MASSsc)*TIMEsc; % Particle density
c1=5639/(LENGTHsc*TIMEsc); % Compression wave velocity of particle
c2=2970/(LENGTHsc*TIMEsc); % Shear wave velocity of particle

%%%Glycerine
% rholiq=1260*LENGTHsc^2/(MASSsc)*TIMEsc; % Liquid density
% cliq=1962/(LENGTHsc*TIMEsc); % Liquid speed of sound

%%%Water
rholiq=1000*LENGTHsc^2/(MASSsc)*TIMEsc; % Liquid density
cliq=1480/(LENGTHsc*TIMEsc); % Liquid speed of sound

x=sym('x'); % x=k*a

x1=x*cliq/c1; 
x2=x*cliq/c2;
n=sym('n'); %Bessel order
n1=sym('n1'); %Bessel order, n+1


%% Bessel functions
jn=sphbes1(n,x);
jn1=sphbes1(n1,x);
djn=(2.^(1/2).*pi.^(1/2).*besselj(n - 1/2, x).*(1./x).^(1./2))./2 - (2.^(1./2).*pi.^(1./2).*besselj(n + 1/2, x).*(n + 1).*(1./x).^(3./2))./2;
ddjn=(2.^(1./2).*pi.^(1/2).*besselj(n + 1/2, x).*(1./x).^(1./2).*(n.^2 + 3.*n - x.^2 + 2))./(2.*x.^2) - 2.^(1./2).*pi.^(1/2).*besselj(n - 1./2, x).*(1./x).^(3./2);

nn=sphbes2(n,x);
nn1=sphbes2(n1,x);
dnn=(2.^(1./2).*pi.^(1./2).*bessely(n - 1./2, x).*(1./x).^(1./2))./2 - (2.^(1./2).*pi.^(1./2).*bessely(n + 1./2, x).*(n + 1).*(1./x).^(3./2))./2;

%% Key variables
Fn=Fcalc(jn,jn1,djn,ddjn,x,x1,x2,rhop,rholiq,n);

[alphn,betan]=alphbetacalc(Fn,jn,jn1,djn,nn,nn1,dnn,x,n);


for ii=0:20
   alphn_ev(ii+1)=subs(alphn,{n n1},{ii ii+1});
   betan_ev(ii+1)=subs(betan,{n n1},{ii ii+1});
end

Yphi=0;

%% Hasegawa (1979), ARF under stationary wave

for ii=1:20
   Yphi=Yphi+(ii)*(-1)^(ii)*(betan_ev(ii)*(1+2*alphn_ev(ii+1))-betan_ev(ii+1)*(1+2*alphn_ev(ii))); 
end

Yphi=Yphi.*8/x^2;

%% Substitution: Substitute any x=k*a value to evaluate ARF
aa=subs(Yphi,x,xeval);
Yst=-double(aa);
